metapho package
===============

Subpackages
-----------

.. toctree::

    metapho.gtkpho

Submodules
----------

metapho.metapho module
----------------------

.. automodule:: metapho.metapho
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: metapho
    :members:
    :undoc-members:
    :show-inheritance:
